@@ -3,8 +3,8 @@
 ;; Copyright (C) 2024-2026 James Cherti | https://www.jamescherti.com/contact/
 
 ;; Author: James Cherti <https://www.jamescherti.com/contact/>
-;; Package-Version: 20260219.249
-;; Package-Revision: 21d5054bf450
+;; Package-Version: 20260222.340
+;; Package-Revision: eeaefca1860f
 ;; URL: https://github.com/jamescherti/buffer-terminator.el
 ;; Keywords: convenience
 ;; Package-Requires: ((emacs "25.1"))
@@ -115,9 +115,10 @@ Default: 10 minutes."
   :type 'integer
   :group 'buffer-terminator
   :set (lambda (symbol value)
-         (buffer-terminator--cancel-timer)
          (set-default symbol value)
-         (buffer-terminator--start-timer value)))
+         (when (bound-and-true-p buffer-terminator-mode)
+           (buffer-terminator--cancel-timer)
+           (buffer-terminator--start-timer value))))
 
 (defvar buffer-terminator-rules-alist
   '(;; Retain special buffers (DO NOT REMOVE).
@@ -307,7 +308,7 @@ The messages are displayed in the *buffer-terminator* buffer."
      (buffer-terminator--insert-message "*buffer-terminator:debug*"
                                         ,(car args) ,@(cdr args))))
 
-(defun buffer-terminator-buffer-visible-p ()
+(defun buffer-terminator--buffer-visible-p ()
   "Return non-nil if the current buffer or any associated buffer is visible.
 
 This includes visibility in any window on any frame or presence in a tab-bar
@@ -368,7 +369,7 @@ base or related buffer is visible."
       t))
 
    ((eq property 'visible)
-    (when (buffer-terminator-buffer-visible-p)
+    (when (buffer-terminator--buffer-visible-p)
       t))
 
    ((eq property 'active)
